@@ -23,6 +23,7 @@
 #include "pa_utils.h"
 
 #include <QString>
+#include <QLineEdit>
 
 MainWindow::MainWindow(QWidget *parent) :
     QMainWindow(parent),
@@ -44,12 +45,19 @@ MainWindow::MainWindow(QWidget *parent) :
     sources = (QStringList *) get_source_names();
 #endif
     ui->sourcesComboBox->addItems(*sources);
+
+#ifdef Q_WS_MAEMO_5
+    ui->sourcesComboBox->setEditable(true);
+    ui->sourcesComboBox->lineEdit()->setAlignment(Qt::AlignHCenter);
+    ui->sourcesComboBox->lineEdit()->setReadOnly(true);
+#endif
+
     connect(ui->sourcesComboBox, SIGNAL(activated(int)), this, SLOT(sourceChanged(int)));
 
 #ifdef Q_WS_MAEMO_5
     connect_to_vu_meter_stream("source.hw0", this);
 #else
-    connect_to_vu_meter_stream(sources->at(index).toLocal8Bit().constData(), this);
+    connect_to_vu_meter_stream(sources->at(0).toLocal8Bit().constData(), this);
 #endif
 
     connect(this, SIGNAL(updateVuMeterSignal(float)), this, SLOT(updateValues(float)), Qt::QueuedConnection);
